/**************************************************************************
 * Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. *
 * See cxx source for full Copyright notice                               *
 **************************************************************************/

//-------------------------------------------------------------------------
//                      Class AliAODSimpleEvent
//  Simple collection of reconstructed tracks, selected from an ESD event
// 
// author: A. Pulvirenti             (email: alberto.pulvirenti@ct.infn.it)
//-------------------------------------------------------------------------

#ifndef ALIAODSIMPLEEVENT_H
#define ALIAODSIMPLEEVENT_H

#include <TArrayI.h>

class TRefArray;

class AliAODSimpleEvent : public TObject
{
public:
	         AliAODSimpleEvent(Int_t evnum = 0, Int_t ntracks = 20000);
	virtual ~AliAODSimpleEvent();
	
	enum EParticleType { kNoType=-1, 
	                     kElectron=0, kMuon=1, 
						 kPion=2, kKaon=3, kProton=4, 
	                     kParticleTypes=5 };
	
	enum EArrayIndex   { kNoIndex=-1, 
	                     kElectronPlus=0, kElectronMinus=1, 
	                     kMuonPlus=2, kMuonMinus=3, 
						 kPionPlus=4, kPionMinus=5, 
						 kKaonPlus=6, kKaonMinus=7, 
						 kProtonPlus=8, kProtonMinus=9,
						 kArrayIndexes=10 };
	
	void        Clear(Option_t *option ="");
	static void Reset(Option_t *option ="");
		
	void AcceptNotRefittedTracks()  			   {fgRejectNoITS=kFALSE;}
	void RejectNotRefittedTracks()  			   {fgRejectNoITS=kTRUE;}
	void UsePerfectPID(Bool_t yesno = kTRUE)	   {fgUsePerfectPID=yesno;}
	void SetEventNumber(Int_t iev)  			   {fEventNumber=iev;}
	void SetPtLimit4PID(Double_t limit) 		   {fgPtLimit4PID=limit;}
	void SetProbThreshold(Double_t th)  		   {fgProbThreshold=th;}
	void SetPriorProb(EParticleType p, Double_t v) {fgPrior[p] = v;}
	
	void SetPrimaryVertex(Double_t x, Double_t y, Double_t z) {fPVx=x;fPVy=y;fPVz=z;}
	
	TArrayI    DoSelection(AliESD *esd, TObject *partList);
	TRefArray *GetTracks(EArrayIndex type);

private:
	
	EArrayIndex    GetArrayIndex(Int_t pdg);   // array index of a given PDG code in the list
	Int_t          BayesianPID(TArrayD &pid);  // performs Bayes combination for realistic PID
	
	Int_t          fEventNumber;         // reference number of event
	Double_t       fPVx;  		         //
	Double_t       fPVy;  	 	         // primary vertex
	Double_t       fPVz;   		         //
	TClonesArray  *fTracks;              // global collection of tracks
	TRefArray     *fRef[kArrayIndexes];  // references to each particle type
	
	static TClonesArray  *fgTracks;         // static collection of tracks
	static Bool_t         fgUsePerfectPID;  // flag for PID method (if it isn't 'perfect', it will be ESD)
	static Double_t       fgPtLimit4PID;    // ESD PID is not made for particles above this limit
	static Double_t       fgProbThreshold;  // tracks with max probability smaller than it are rejected
	static TArrayD        fgPrior;          // prior probabilities for ESD PID
	static TArrayD        fgDefMass;        // true particle masses
	static TArrayI        fgDefPDG;         // true particle PDG codes
	static Bool_t         fgRejectNoITS;    // if 'TRUE', all tracks not ITS-refitted, are rejected

	ClassDef(AliAODSimpleEvent,1);
};

#endif
