/**************************************************************************
 * Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. *
 *                                                                        *
 * Author: The ALICE Off-line Project.                                    *
 * Contributors are mentioned in the code where appropriate.              *
 *                                                                        *
 * Permission to use, copy, modify and distribute this software and its   *
 * documentation strictly for non-commercial purposes is hereby granted   *
 * without fee, provided that the above copyright notice appears in all   *
 * copies and that both the copyright notice and this permission notice   *
 * appear in the supporting documentation. The authors make no claims     *
 * about the suitability of this software for any purpose. It is          *
 * provided "as is" without express or implied warranty.                  *
 **************************************************************************/
 
//-------------------------------------------------------------------------
//                      Class AliAODSimpleTrack
//  
//           A simple object which describes a reconstructed track
//           with some references to its related generated particle
//           and some facilities which could help in composing its
//           4-momentum, for resonance study.
// 
// author: A. Pulvirenti             (email: alberto.pulvirenti@ct.infn.it)
//-------------------------------------------------------------------------

#include <Riostream.h>

#include <TParticle.h>
#include <TObjArray.h>

#include "AliESD.h"
#include "AliStack.h"
#include "AliESDtrack.h"
#include "AliAODSimpleTrack.h"

ClassImp(AliAODSimpleTrack)

//--------------------------------------------------------------------------------------------------------
AliAODSimpleTrack::AliAODSimpleTrack(Int_t nParticleTypes) : fPID(nParticleTypes)
// 
// Default constructor.
// Its unique argument defines how many PID weights 
// should be expected in a 'realistic' PID (ESD). 
// Actually, it should be the same as AliESDtrack::kSPECIES (=5), 
// which is used as default (see header file).
{ 
	fIndex = fLabel = 0;
	fMotherLabel = -1;
	fMotherPDG = 0;
	
	fPx = fPy = fPz = fMass = 0.0;
	fVx = fVy = fVz = 0.0;
}
//--------------------------------------------------------------------------------------------------------
inline TLorentzVector AliAODSimpleTrack::Get4Momentum()
//
// Creates a TLorentzVector object
// containing the 4-momentum of the track
//
{
	TLorentzVector output; 
	output.SetXYZM(fPx,fPy,fPz,fMass); 
	return output;
}
//--------------------------------------------------------------------------------------------------------
inline TVector3 AliAODSimpleTrack::Get3Momentum()
//
// Creates a TVector3 object 
// containing the vector momentum (px,py,pz)
{
	TVector3 output; 
	output.SetXYZ(fPx,fPy,fPz); 
	return output;
}
//--------------------------------------------------------------------------------------------------------
inline TVector3 AliAODSimpleTrack::AliAODSimpleTrack::GetVertex()
// Creates a TVector3 object
// containing the (x,y,z) of the point of closest approach
// to primary vertex (as obtained from track fitting)
{
	TVector3 output; 
	output.SetXYZ(fVx,fVy,fVz); 
	return output;
}
