/**************************************************************************
 * Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. *
 * See cxx source for full Copyright notice                               *
 **************************************************************************/

//-------------------------------------------------------------------------
//                      Class AliAODSimpleTrack
//  
//           A simple object which describes a reconstructed track
//           with some references to its related generated particle
//           and some facilities which could help in composing its
//           4-momentum, for resonance study.
// 
// author: A. Pulvirenti             (email: alberto.pulvirenti@ct.infn.it)
//-------------------------------------------------------------------------

#ifndef ALIAODSIMPLETRACK_H
#define ALIAODSIMPLETRACK_H

#include <TArrayD.h>

class AliAODSimpleTrack : public TObject
{
public:

	         AliAODSimpleTrack(Int_t nParticleTypes = 5);
	virtual ~AliAODSimpleTrack() { }
	
	Int_t&  Index()       {return fIndex;}
	Int_t&  Label()       {return fLabel;}
	Int_t&  MotherLabel() {return fMotherLabel;}
	Int_t&  MotherPDG()   {return fMotherPDG;}
	
	void    SetMass(Double_t mass)  {fMass=mass;}
	void    SetPID(TArrayD pid)     {fPID.Copy(pid);}
	void    SetPID(Double_t * pid)  {fPID.Adopt(fPID.GetSize(), pid);}
	
	void    SetPxPyPz(Double_t px, Double_t py, Double_t pz) {fPx=px;fPy=py;fPz=pz;}
	void    SetVxVyVz(Double_t vx, Double_t vy, Double_t vz) {fVx=vx;fVy=vy;fVz=vz;}

	TLorentzVector  Get4Momentum();
	TVector3        Get3Momentum();
	TVector3        GetVertex();
	
private:

	Int_t    fIndex;       // index of track in AliESD object
	Int_t    fLabel;       // GEANT label of related particle
	Int_t    fMotherLabel; // GEANT label of mother (if secondary)
	Int_t    fMotherPDG;   // PDG code of mother
		
	Double_t fPx;          // 
	Double_t fPy;          // vector momentum
	Double_t fPz;          //
	Double_t fMass;        //
		
	Double_t fVx;          // 
	Double_t fVy;          // production vertex
	Double_t fVz;          //
		
	TArrayD  fPID;         // particle PID weights
	
	ClassDef(AliAODSimpleTrack,1)
};

#endif
