//
// Perform selection of pions & kaons in a group of events
//
void AliKStarSelect
(
	Int_t first = 1, 
	Int_t last = 3,
	Bool_t usePerfectPID = kTRUE,
	Bool_t loadMC = kTRUE,
	Double_t ptLimitUsePID = 4.0,
	Option_t *indir = "3800withMC",
	Option_t *outname = "prova"
)
{
	gSystem->Load("libANALYSIS.so");
	
	// check on limits
	if (first < 0) first = 0;
	
	// Create chains to collect data from all selected events
	TChain *tESD = new TChain("esdTree");
	TChain *tMC = 0;
	if (loadMC) tMC = new TChain("mcStackTree");
	for (Int_t iev = first; iev <= last; iev++) {
		tESD->Add(Form("/home/alice/disk/pdc04/%s/%d.root", indir, iev));
		if (loadMC) tMC->Add(Form("/home/alice/disk/pdc04/%s/%d.root", indir, iev));
	}
	
	// Link branches
	AliESD *esd = 0;
	tESD->SetBranchAddress("ESD", &esd);
	TClonesArray *pArrayMC = 0;
	if (loadMC) {
		pArrayMC = new TClonesArray("TParticle");
		tMC->SetBranchAddress("Stack", &pArrayMC);
	}
	
	// Count events (just a check, the two numbers should be equal)
	Int_t nev = (Int_t)tESD->GetEntries();
	if (loadMC) {
		Int_t nevMC = (Int_t)tMC->GetEntries();
		if (nevMC < nev) nev = nevMC;
	}
	
	// Define overall behaviour parameters
	Double_t prior[5] = {0.042, 0.124, 0.655, 0.041, 0.130};
	AliAODSimpleEvent::SetPriorProb(AliAODSimpleEvent::kElectron, prior[0]);
	AliAODSimpleEvent::SetPriorProb(AliAODSimpleEvent::kMuon, prior[1]);
	AliAODSimpleEvent::SetPriorProb(AliAODSimpleEvent::kPion, prior[2]);
	AliAODSimpleEvent::SetPriorProb(AliAODSimpleEvent::kKaon, prior[3]);
	AliAODSimpleEvent::SetPriorProb(AliAODSimpleEvent::kProton, prior[4]);
	AliAODSimpleEvent::UsePerfectPID(usePerfectPID);
	AliAODSimpleEvent::SetPtLimit4PID(ptLimitUsePID);
	
	// Open output file & define output tree
	TFile *file = new TFile(Form("%s.sel.root", outname), "RECREATE");
	TTree *outTree = new TTree("Selections", "Selections from events");
	outTree->SetAutoSave(1000000000);  // autosave when 1 Gbyte written
	AliAODSimpleEvent *event = new AliAODSimpleEvent;
	TTree::SetBranchStyle(1);
	TBranch *branch = outTree->Branch("events", "AliAODSimpleEvent", &event, 32000, 1);
	branch->SetAutoDelete(kFALSE);
	
	// Loop on all events
	Int_t ntracks = 0;
	for (Int_t iev = 0; iev < nev; iev++) {

		// get event
		cout << "\rEvent " << iev << ":" << endl;
		tESD->GetEntry(iev);
		if (loadMC) tMC->GetEntry(iev);
		
		// setup analysis
		TArrayI nsel = event->DoSelection(esd, pArrayMC);
		cout << "PI+ = " << nsel[AliAODSimpleEvent::kPionPlus] << endl;
		cout << "PI- = " << nsel[AliAODSimpleEvent::kPionMinus] << endl;
		cout << "K+  = " << nsel[AliAODSimpleEvent::kKaonPlus] << endl;
		cout << "K-  = " << nsel[AliAODSimpleEvent::kKaonMinus] << endl << endl;
		
		outTree->Fill();
		//gObjectTable->Print();

	}
	cout << "Maximum number of tracks = " << ntracks << endl;
	
	outTree->Write();
	file->Close();
}
